@@ -6,9 +6,7 @@ def open_file(filepath):
         if '~/' in filepath:
             filepath = filepath.replace('~/', detect())
         with open(filepath, 'r') as file:
-            lines = file.read()
-            lines = lines.strip()
-        lines = lines.split('\n')
+            lines = file.read().strip()
         return lines
     except FileNotFoundError:
         print(f"File NotFound({filepath})")
@@ -21,3 +19,11 @@ def save_output(filename, text):
     with open(filename, '+a') as file:
         file.write(str(text))
         file.write('\n')
+
+
+def open_headers_file(headers_file):
+    if '~/' in headers_file:
+        headers_file = headers_file.replace('~/', detect())
+    with open(headers_file) as f:
+        headers = dict(line.split(': ', 1) for line in f.read().splitlines())
+    return headers
